=== modified file 'bzrlib/hooks.py'
--- bzrlib/hooks.py	2010-09-28 07:34:29 +0000
+++ bzrlib/hooks.py	2010-10-14 15:46:51 +0000
@@ -80,6 +80,7 @@
     ('bzrlib.smart.client', '_SmartClient.hooks', 'SmartClientHooks'),
     ('bzrlib.smart.server', 'SmartTCPServer.hooks', 'SmartServerHooks'),
     ('bzrlib.status', 'hooks', 'StatusHooks'),
+    ('bzrlib.transport', 'Transport.hooks', 'TransportHooks'),
     ('bzrlib.version_info_formats.format_rio', 'RioVersionInfoBuilder.hooks',
         'RioVersionInfoBuilderHooks'),
     ('bzrlib.merge_directive', 'BaseMergeDirective.hooks',

=== modified file 'bzrlib/tests/test_transport.py'
--- bzrlib/tests/test_transport.py	2010-09-01 18:43:32 +0000
+++ bzrlib/tests/test_transport.py	2010-10-14 15:46:51 +0000
@@ -464,6 +464,29 @@
             server.stop_server()
 
 
+class TestHooks(tests.TestCase):
+    """Basic tests for transport hooks"""
+
+    def _get_connected_transport(self):
+        return transport.ConnectedTransport("bogus:nowhere")
+
+    def test_transporthooks_initialisation(self):
+    	"""Check all expected transport hook points are set up"""
+    	hookpoint = transport.TransportHooks()
+    	self.assertTrue("post_connect" in hookpoint,
+    	    "post_connect not in %s" % (hookpoint,))
+
+    def test_post_connect(self):
+    	"""Ensure the post_connect hook is called when _set_transport is"""
+    	calls = []
+    	transport.Transport.hooks.install_named_hook("post_connect",
+    	    calls.append, None)
+        t = self._get_connected_transport()
+        self.assertLength(0, calls)
+        t._set_connection("connection", "auth")
+        self.assertEqual(calls, [t])
+
+
 class PathFilteringDecoratorTransportTest(tests.TestCase):
     """Pathfilter decoration specific tests."""
 

=== modified file 'bzrlib/transport/__init__.py'
--- bzrlib/transport/__init__.py	2010-06-18 15:38:20 +0000
+++ bzrlib/transport/__init__.py	2010-10-14 15:46:51 +0000
@@ -49,10 +49,11 @@
 from bzrlib.symbol_versioning import (
         DEPRECATED_PARAMETER,
         )
-from bzrlib.trace import (
-    mutter,
+from bzrlib import (
+    hooks,
+    registry,
+    trace,
     )
-from bzrlib import registry
 
 
 # a dictionary of open file streams. Keys are absolute paths, values are
@@ -267,6 +268,16 @@
         self.transport.append_bytes(self.relpath, bytes)
 
 
+class TransportHooks(hooks.Hooks):
+    """Mapping of hook names to registered callbacks for transport hooks"""
+    def __init__(self):
+        super(TransportHooks, self).__init__()
+        self.create_hook(hooks.HookPoint("post_connect",
+            "Called after a new connection is established or a reconnect "
+            "occurs. The connected transport instance is the sole argument "
+            "passed", (2, 3), None))
+
+
 class Transport(object):
     """This class encapsulates methods for retrieving or putting a file
     from/to a storage location.
@@ -291,6 +302,8 @@
     #       where the biggest benefit between combining reads and
     #       and seeking is. Consider a runtime auto-tune.
     _bytes_to_read_before_seek = 0
+    
+    hooks = TransportHooks()
 
     def __init__(self, base):
         super(Transport, self).__init__()
@@ -1492,6 +1505,10 @@
         """
         self._shared_connection.connection = connection
         self._shared_connection.credentials = credentials
+        for hook in self.hooks["post_connect"]:
+            # GZ 2010-10-14: Should the hook be passed the new connection and
+            #                credentials too or does opaque really mean that?
+            hook(self)
 
     def _get_connection(self):
         """Returns the transport specific connection object."""
@@ -1589,7 +1606,6 @@
             raise errors.UnsupportedProtocol(base, last_err)
         # This doesn't look like a protocol, consider it a local path
         new_base = urlutils.local_path_to_url(base)
-        # mutter('converting os path %r => url %s', base, new_base)
         return new_base
 
     # Catch any URLs which are passing Unicode rather than ASCII
@@ -1637,8 +1653,8 @@
         try:
             return factory.get_obj()(base), None
         except errors.DependencyNotPresent, e:
-            mutter("failed to instantiate transport %r for %r: %r" %
-                    (factory, base, e))
+            trace.mutter("failed to instantiate transport %r for %r: %r" %
+                         (factory, base, e))
             last_err = e
             continue
     return None, last_err

